@@ -13,15 +13,19 @@ CGI::Untaint::CountyStateProvince::US - Add U.S. states to CGI::Untaint::CountyS
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
-Adds a list of U.S. states to the list of counties/state/provinces
+The module validates that a given input,
+represents a valid U.S. state.
+It supports both full state names (e.g., "Maryland") and two-letter state abbreviations (e.g., "MD").
+
+Adds a list of U.S. states to the list of counties/states/provinces
 which are known by the CGI::Untaint::CountyStateProvince validator allowing you
 to verify that a field in an HTML form contains a valid U.S. state.
 
@@ -39,11 +43,11 @@ CGI::Untaint, otherwise it won't work.
 
 =cut
 
-=head1 SUBSOUTINES/METHODS
+=head1 SUBROUTINES/METHODS
 
 =head2 is_valid
 
-Validates the data, setting the data to be the two letter abbreviation for the
+Validates the data, setting the data to be the two-letter abbreviation for the
 given state.  See CGI::Untaint::is_valid.
 
 =cut
@@ -51,7 +55,8 @@ given state.  See CGI::Untaint::is_valid.
 sub is_valid {
 	my $self = shift;
 
-	my $value = uc($self->value);
+	my $value = uc($self->value());
+	$value =~ s/^\s+|\s+$//g;	# Trim whitespace
 
 	if($value =~ /([A-Z][A-Z\s]+)/) {
 		$value = $1;
@@ -77,7 +82,7 @@ sub is_valid {
 
 	$state = $self->{_validator}->full_name($value);
 	if($state && ($state ne 'unknown')) {
-		# Given two letter abbreviation
+		# Given two-letter abbreviation
 		return $value;
 	}
 
@@ -86,8 +91,9 @@ sub is_valid {
 
 =head2 value
 
-Sets the raw data which is to be validated.  Called by the superclass, you
-are unlikely to want to call it.
+Sets the raw data to be validated.
+Called by the superclass,
+you are unlikely to want to call it.
 
 =cut
 
@@ -113,17 +119,17 @@ Nigel Horne, C<< <njh at bandsman.co.uk> >>
 
 =head1 BUGS
 
-Only two letter abbreviations are allowable, so 'Mass' won't work for
-Massachusetts.
+Only two-letter abbreviations are allowable,
+so 'Mass' won't work for Massachusetts.
 
 Please report any bugs or feature requests to C<bug-cgi-untaint-csp-us at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Untaint-CountyStateProvince>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CGI-Untaint-CountyStateProvince>.
+I will be notified,
+and then you'll automatically be notified of the progress of your bug as I make changes.
 
 =head1 SEE ALSO
 
-CGI::Untaint::CountyStateProvince, CGI::Untaint
+L<CGI::Untaint::CountyStateProvince>, L<CGI::Untaint>, L<Locale::SubCountry>
 
 =head1 SUPPORT
 
@@ -131,7 +137,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc CGI::Untaint::CountyStateProvince::US
 
-
 You can also look for information at:
 
 =over 4
@@ -140,10 +145,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=CGI-Untaint-CountyStateProvince-US>
 
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/CGI-Untaint-CountyStateProvince-US>
-
 =item * Search CPAN
 
 L<http://search.cpan.org/dist/CGI-Untaint-CountyStateProvince-US>
@@ -152,10 +153,9 @@ L<http://search.cpan.org/dist/CGI-Untaint-CountyStateProvince-US>
 
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2019 Nigel Horne.
+Copyright 2012-2025 Nigel Horne.
 
 This program is released under the following licence: GPL2
 
